|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r79486 - trunk/tools/build/v2/engine
From: jurko.gospodnetic_at_[hidden]
Date: 2012-07-13 18:48:59
Author: jurko
Date: 2012-07-13 18:48:58 EDT (Fri, 13 Jul 2012)
New Revision: 79486
URL: http://svn.boost.org/trac/boost/changeset/79486
Log:
Boost Jam code cleanup - minor stylistic code changes & comment updates.
Text files modified:
trunk/tools/build/v2/engine/timestamp.c | 32 ++++++++++++++++++++++++--------
1 files changed, 24 insertions(+), 8 deletions(-)
Modified: trunk/tools/build/v2/engine/timestamp.c
==============================================================================
--- trunk/tools/build/v2/engine/timestamp.c (original)
+++ trunk/tools/build/v2/engine/timestamp.c 2012-07-13 18:48:58 EDT (Fri, 13 Jul 2012)
@@ -12,6 +12,15 @@
/*
* timestamp.c - get the timestamp of a file or archive member
+ *
+ * External routines:
+ * timestamp_from_target() - return timestamp on a file, if present
+ * timestamp_done() - free timestamp tables
+ *
+ * Internal routines:
+ * time_enter() - internal worker callback for scanning archives &
+ * directories
+ * free_timestamps() - worker function for freeing timestamp table contents
*/
#include "jam.h"
@@ -28,9 +37,7 @@
* BINDING - all known files
*/
-typedef struct _binding BINDING;
-
-struct _binding {
+typedef struct _binding {
OBJECT * name;
short flags;
@@ -46,7 +53,7 @@
/* update time - 0 if not exist */
time_t time;
-};
+} BINDING;
static struct hash * bindhash = 0;
static void time_enter( void *, OBJECT *, int const found, time_t );
@@ -62,10 +69,10 @@
/*
* timestamp() - return timestamp on a file, if present.
*/
-void timestamp( OBJECT * target, time_t * time )
+void timestamp_from_target( OBJECT * target, time_t * time )
{
PROFILE_ENTER( timestamp );
@@ -180,6 +187,10 @@
}
+/*
+ * time_enter() - internal worker callback for scanning archives & directories
+ */
+
static void time_enter( void * closure, OBJECT * target, int const found,
time_t time )
{
@@ -206,6 +217,11 @@
object_free( target );
}
+
+/*
+ * free_timestamps() - worker function for freeing timestamp table contents
+ */
+
static void free_timestamps( void * xbinding, void * data )
{
object_free( ((BINDING *)xbinding)->name );
@@ -213,10 +229,10 @@
/*
* stamps_done() - free timestamp tables.
*/
-void stamps_done()
+void timestamp_done()
{
if ( bindhash )
{
@@ -62,10 +69,10 @@
/*
- * timestamp() - return timestamp on a file, if present.
+ * timestamp_from_target() - return timestamp on a file, if present
*/
@@ -213,10 +229,10 @@
/*
- * stamps_done() - free timestamp tables.
+ * timestamp_done() - free timestamp tables
*/
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk